@@ -80,19 +80,20 @@ class Source(DaeObject):
     @staticmethod
     def load(collada, localscope, node):
         sourceid = node.get('id')
-        arraynode = node.find(tag('float_array'))
+        arraynode = node.find(collada.tag('float_array'))
         if not arraynode is None:
             return FloatSource.load(collada, localscope, node)
 
-        arraynode = node.find(tag('IDREF_array'))
+        arraynode = node.find(collada.tag('IDREF_array'))
         if not arraynode is None:
             return IDRefSource.load(collada, localscope, node)
 
-        arraynode = node.find(tag('Name_array'))
+        arraynode = node.find(collada.tag('Name_array'))
         if not arraynode is None:
             return NameSource.load(collada, localscope, node)
 
-        if arraynode is None: raise DaeIncompleteError('No array found in source %s' % sourceid)
+        if arraynode is None:
+            raise DaeIncompleteError('No array found in source %s' % sourceid)
 
 
 class FloatSource(Source):
@@ -101,7 +102,7 @@ class FloatSource(Source):
 
     If ``f`` is an instance of :class:`collada.source.FloatSource`, then
     ``len(f)`` is the length of the shaped source. ``len(f)*len(f.components)``
-    would give you the number of values in the source. ``f[i]`` is the i\ :sup:`th`
+    would give you the number of values in the source. ``f[i]`` is the i\\ :sup:`th`
     item in the source array.
     """
 
@@ -178,16 +179,16 @@ class FloatSource(Source):
     @staticmethod
     def load( collada, localscope, node ):
         sourceid = node.get('id')
-        arraynode = node.find(tag('float_array'))
+        arraynode = node.find(collada.tag('float_array'))
         if arraynode is None: raise DaeIncompleteError('No float_array in source node')
-        if arraynode.text is None:
+        if arraynode.text is None or arraynode.text.isspace():
             data = numpy.array([], dtype=numpy.float32)
         else:
             try: data = numpy.fromstring(arraynode.text, dtype=numpy.float32, sep=' ')
             except ValueError: raise DaeMalformedError('Corrupted float array')
         data[numpy.isnan(data)] = 0
 
-        paramnodes = node.findall('%s/%s/%s'%(tag('technique_common'), tag('accessor'), tag('param')))
+        paramnodes = node.findall('%s/%s/%s'%(collada.tag('technique_common'), collada.tag('accessor'), collada.tag('param')))
         if not paramnodes: raise DaeIncompleteError('No accessor info in source node')
         components = [ param.get('name') for param in paramnodes ]
         if len(components) == 2 and components[0] == 'U' and components[1] == 'V':
@@ -210,7 +211,7 @@ class IDRefSource(Source):
 
     If ``r`` is an instance of :class:`collada.source.IDRefSource`, then
     ``len(r)`` is the length of the shaped source. ``len(r)*len(r.components)``
-    would give you the number of values in the source. ``r[i]`` is the i\ :sup:`th`
+    would give you the number of values in the source. ``r[i]`` is the i\\ :sup:`th`
     item in the source array.
 
     """
@@ -289,13 +290,13 @@ class IDRefSource(Source):
         sourceid = node.get('id')
         arraynode = node.find(tag('IDREF_array'))
         if arraynode is None: raise DaeIncompleteError('No IDREF_array in source node')
-        if arraynode.text is None:
+        if arraynode.text is None or arraynode.text.isspace():
             values = []
         else:
             try: values = [v for v in arraynode.text.split()]
             except ValueError: raise DaeMalformedError('Corrupted IDREF array')
         data = numpy.array( values, dtype=numpy.unicode_ )
-        paramnodes = node.findall('%s/%s/%s'%(tag('technique_common'), tag('accessor'), tag('param')))
+        paramnodes = node.findall('%s/%s/%s'%(collada.tag('technique_common'), collada.tag('accessor'), collada.tag('param')))
         if not paramnodes: raise DaeIncompleteError('No accessor info in source node')
         components = [ param.get('name') for param in paramnodes ]
         return IDRefSource( sourceid, data, tuple(components), xmlnode=node )
@@ -309,7 +310,7 @@ class NameSource(Source):
 
     If ``n`` is an instance of :class:`collada.source.NameSource`, then
     ``len(n)`` is the length of the shaped source. ``len(n)*len(n.components)``
-    would give you the number of values in the source. ``n[i]`` is the i\ :sup:`th`
+    would give you the number of values in the source. ``n[i]`` is the i\\ :sup:`th`
     item in the source array.
 
     """
@@ -388,13 +389,14 @@ class NameSource(Source):
         sourceid = node.get('id')
         arraynode = node.find(tag('Name_array'))
         if arraynode is None: raise DaeIncompleteError('No Name_array in source node')
-        if arraynode.text is None:
+        if arraynode.text is None or arraynode.text.isspace():
             values = []
         else:
             try: values = [v for v in arraynode.text.split()]
             except ValueError: raise DaeMalformedError('Corrupted Name array')
         data = numpy.array( values, dtype=numpy.unicode_ )
-        paramnodes = node.findall('%s/%s/%s'%(tag('technique_common'), tag('accessor'), tag('param')))
+        paramnodes = node.findall('%s/%s/%s'%(tag('technique_common'), tag('accessor'), tag
+                                              ('param')))
         if not paramnodes: raise DaeIncompleteError('No accessor info in source node')
         components = [ param.get('name') for param in paramnodes ]
         return NameSource( sourceid, data, tuple(components), xmlnode=node )
